@@ -92,10 +92,12 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
         return self.auth
 
     def close (self):
+        if self._closed:
+            return
+
         # sometimes socket is not closed at once
         # possibly related with SSL socket
         # then prevent doble callbacking in request_handler
-
         if self.socket:
             # self.socket is still None, when DNS not found
             asynchat.async_chat.close (self)
@@ -109,7 +111,6 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
         self._closed = True
 
         if not self.handler:
-            # return to the pool
             return self.set_active (False)
 
         if not self.errcode:
@@ -124,28 +125,31 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
             self.trace ()
 
         if not keep_active:
-            self.set_active (False)
             if self.errcode not in (704, 712, 722):
                 # controlled shutdown
                 self.logger (
-                    "..socket %s has been closed%s" % ("%s:%d" % self.address, self.errcode != 700 and " (reason: %d)".format (self.errcode) or ''),
+                    "..socket %s has been closed%s" % ("%s:%d" % self.address, self.errcode != 700 and " (reason: {})".format (self.errcode) or ''),
                     "info"
                 )
+            self.set_active (False)
+            # IMP: DO NOT touch self.handelr
+            # IMP: DO NOT CALL end_tran (), not like dbconnect, this is controlled by handler
+            # IMP: ensure test level4/test_example_apps_with_aquests.py
         # DO NOT Change any props, because may be request has been restarted
 
     def end_tran (self):
-        if DEBUG:
-            self.logger ('end_tran {rid:%s} %s' % (self.handler.request.meta.get ('req_id', -1), self.handler.request.uri), 'debug')
+        # MUST CALL ONLY SUCCESSE, otherwaise already called by self.close ()
         if not self.keep_connect:
             self.disconnect ()
         elif not self.backend:
             self.del_channel ()
-        self.isactive () and self.set_active (False)
+        # IMP: DO NOT touch self.handelr
+        # IMP: ensure test level4/test_example_apps_with_aquests.py
+        self.set_active (False)
 
     def get_proto (self):
         with self.lock:
-            p = self._proto
-        return p
+            return self._proto
 
     def set_proto (self, proto):
         with self.lock:
@@ -346,6 +350,7 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
                 self.initiate_send ()
 
     def handle_abort (self):
+        self.handler = None
         self.close ()
 
     def handle_close (self, code = 700, msg = ""):
@@ -374,8 +379,8 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
         self.handler.found_terminator ()
 
     def disconnect (self):
-        # no error
-        self.handle_close (0)
+        self.errcode = 0
+        self.close ()
 
     def reconnect (self):
         self.disconnect ()
