@@ -19,9 +19,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asynchat.async_chat):
 		self.ac_in_buffer = b''
 		self.incoming = []
 		self.producer_fifo.clear()
-
 		dbconnect.AsynDBConnect.close (self)
-		self.logger ("[info] ..dbo %s:%d has been closed" % self.address)
 
 	def handle_connect (self):
 		self.set_event_time ()
@@ -124,12 +122,12 @@ class AsynConnect (dbconnect.AsynDBConnect, asynchat.async_chat):
 
 		if not self.num_elements:
 			self.has_result = True
-			self.end_tran ()
+			self.close_case (commit = True)
 
-	def end_tran (self):
+	def close_case (self, commit = False):
 		if self.request:
 			self.request.handle_result (None, self.expt, self.fetchall ())
-		dbconnect.AsynDBConnect.end_tran (self)
+		dbconnect.AsynDBConnect.close_case (self, commit)
 
 	def begin_tran (self, request):
 		dbconnect.AsynDBConnect.begin_tran (self, request)
