@@ -84,11 +84,16 @@ class DBConnect (baseconnect.BaseConnect):
             return
         addr = type (self.address) is tuple and ("%s:%d" % self.address) or str (self.address)
         self.logger ("[info] ..dbo %s has been closed" % addr)
-        self.end_tran ()
+        self.close_case ()
+        self.set_active (False)
+
+    def close_case (self, commit = False):
+        # IMP: must be call on end of all request session
+        self.request = None
+        commit and self.end_tran ()
 
     def end_tran (self):
         # MUST CALL ONLY SUCCESSE, otherwaise already called by self.close ()
-        self.request = None
         self.set_active (False)
 
     def clean_shutdown_control (self, phase, time_in_this_phase):
@@ -182,6 +187,6 @@ class AsynDBConnect (DBConnect):
             del map[fd]
 
     def end_tran (self):
-        super ().end_tran ()
-        if not self._closed and not self.backend:
+        if not self.backend:
             self.del_channel ()
+        super ().end_tran ()
