@@ -37,21 +37,20 @@ class Postgres (SynConnect):
         except:
             self.handle_error ()
         else:
-            self.end_tran ()
+            self.close_case (commit = True)
 
 class Redis (Postgres):
-    def close (self, deactive = 1):
+    def close (self):
         if self.conn:
             self.conn.close ()
             self.conn = None
         self.connected = False
-        DBConnect.close (self, deactive)
+        DBConnect.close (self)
 
-    def end_tran (self):
+    def close_case (self, commit = False):
         if self.request:
             self.request.handle_result (None, self.expt, self.fetchall ())
-            self.request = None
-        super ().end_tran ()
+        super ().AsynDBConnect.close_case (self, commit)
 
     def connect (self):
         host, port = self.address
@@ -75,7 +74,7 @@ class Redis (Postgres):
         except:
             self.handle_error ()
         else:
-            self.end_tran ()
+            self.close_case (commit = True)
 
 class MongoDB (Redis):
     def prefetch (self):
