@@ -25,9 +25,7 @@ class SynConnect (asynpsycopg2.AsynConnect):
 		pass
 
 	def close (self):
-		if self.cur:
-			self.cur.close ()
-			self.cur = None
+		self.close_cursor ()
 		if self.conn:
 			self.conn.close ()
 			self.conn = None
@@ -62,4 +60,4 @@ class SynConnect (asynpsycopg2.AsynConnect):
 		except:
 			self.handle_error ()
 		else:
-			self.end_tran ()
+			self.close_case (commit = True)
